==> tuia-explore-center-api-1.0.2-20190826.024610-3-sources.jar: cn/tuia/explore/center/api/dto/rsp/PostDto.java <==
package cn.tuia.explore.center.api.dto.rsp;

import cn.tuia.explore.center.api.dto.req.PostPublishDto;

import java.util.Date;

/**
 * @author ElinZhou zhoufeng@duiba.com.cn
 * @version $Id: PostDto.java , v 0.1 2019-05-23 17:41 ElinZhou Exp $
 */
public class PostDto extends PostPublishDto {
    private static final long serialVersionUID = 7398636528456083335L;
    /**
     * 帖子id
     */
    private Long id;

    /**
     * 分享次数
     */
    private long shareTimes;

    /**
     * 评论次数
     */
    private long commentTimes;

    /**
     * 点赞次数
     */
    private long likeTimes;

    /**
     * 时间描述
     */
    private String publishTimeDesc;

    /**
     * 时间描述
     */
    private Date publishTime;

    /**
     * 图片数量
     */
    private Integer imageCount;

    /**
     * 当前用户是否关注了该作者
     */
    private boolean follow;

    /**
     * 一同观看的人数
     */
    private Long viewCount;

    /**
     * 动态类型 0：普通动态 1：专题
     */
    private int type;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public long getShareTimes() {
        return shareTimes;
    }

    public void setShareTimes(long shareTimes) {
        this.shareTimes = shareTimes;
    }

    public long getCommentTimes() {
        return commentTimes;
    }

    public void setCommentTimes(long commentTimes) {
        this.commentTimes = commentTimes;
    }

    public long getLikeTimes() {
        return likeTimes;
    }

    public void setLikeTimes(long likeTimes) {
        this.likeTimes = likeTimes;
    }

    public String getPublishTimeDesc() {
        return publishTimeDesc;
    }

    public void setPublishTimeDesc(String publishTimeDesc) {
        this.publishTimeDesc = publishTimeDesc;
    }

    public Date getPublishTime() {
        return publishTime;
    }

    public void setPublishTime(Date publishTime) {
        this.publishTime = publishTime;
    }

    public Integer getImageCount() {
        return imageCount;
    }

    public void setImageCount(Integer imageCount) {
        this.imageCount = imageCount;
    }

    public boolean isFollow() {
        return follow;
    }

    public void setFollow(boolean follow) {
        this.follow = follow;
    }

    public Long getViewCount() {
        return viewCount;
    }

    public void setViewCount(Long viewCount) {
        this.viewCount = viewCount;
    }

    public int getType() {
        return type;
    }

    public void setType(int type) {
        this.type = type;
    }
}

==> tuia-explore-center-api-1.1.0-20190919.104205-16-sources.jar: cn/tuia/explore/center/api/dto/rsp/PostDto.java <==
package cn.tuia.explore.center.api.dto.rsp;

import cn.tuia.explore.center.api.dto.req.PostPublishDto;

import java.util.Date;

/**
 * @author ElinZhou zhoufeng@duiba.com.cn
 * @version $Id: PostDto.java , v 0.1 2019-05-23 17:41 ElinZhou Exp $
 */
public class PostDto extends PostPublishDto {
    private static final long serialVersionUID = 7398636528456083335L;
    /**
     * 帖子id
     */
    private Long id;

    /**
     * 分享次数
     */
    private long shareTimes;

    /**
     * 评论次数
     */
    private long commentTimes;

    /**
     * 点赞次数
     */
    private long likeTimes;

    /**
     * 时间描述
     */
    private String publishTimeDesc;

    /**
     * 时间描述
     */
    private Date publishTime;

    /**
     * 图片数量
     */
    private Integer imageCount;

    /**
     * 当前用户是否关注了该作者
     */
    private boolean follow;

    /**
     * 一同观看的人数
     */
    private Long viewCount;

    /**
     * 动态类型 0：普通动态 1：专题
     */
    private int type;

    private Integer contentCode;

    public Integer getContentCode() {
        return contentCode;
    }

    public void setContentCode(Integer contentCode) {
        this.contentCode = contentCode;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public long getShareTimes() {
        return shareTimes;
    }

    public void setShareTimes(long shareTimes) {
        this.shareTimes = shareTimes;
    }

    public long getCommentTimes() {
        return commentTimes;
    }

    public void setCommentTimes(long commentTimes) {
        this.commentTimes = commentTimes;
    }

    public long getLikeTimes() {
        return likeTimes;
    }

    public void setLikeTimes(long likeTimes) {
        this.likeTimes = likeTimes;
    }

    public String getPublishTimeDesc() {
        return publishTimeDesc;
    }

    public void setPublishTimeDesc(String publishTimeDesc) {
        this.publishTimeDesc = publishTimeDesc;
    }

    public Date getPublishTime() {
        return publishTime;
    }

    public void setPublishTime(Date publishTime) {
        this.publishTime = publishTime;
    }

    public Integer getImageCount() {
        return imageCount;
    }

    public void setImageCount(Integer imageCount) {
        this.imageCount = imageCount;
    }

    public boolean isFollow() {
        return follow;
    }

    public void setFollow(boolean follow) {
        this.follow = follow;
    }

    public Long getViewCount() {
        return viewCount;
    }

    public void setViewCount(Long viewCount) {
        this.viewCount = viewCount;
    }

    public int getType() {
        return type;
    }

    public void setType(int type) {
        this.type = type;
    }
}
